@@ -1,6 +1,6 @@
 /*
- * Copyright (c) 2003 Matteo Frigo
- * Copyright (c) 2003 Massachusetts Institute of Technology
+ * Copyright (c) 2003, 2007-14 Matteo Frigo
+ * Copyright (c) 2003, 2007-14 Massachusetts Institute of Technology
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -14,11 +14,10 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
  *
  */
 
-/* $Id: problem.c,v 1.34 2003/05/04 23:37:09 athena Exp $ */
 
 #include "dft.h"
 #include <stddef.h>
@@ -35,8 +34,8 @@ static void hash(const problem *p_, md5 *m)
      const problem_dft *p = (const problem_dft *) p_;
      X(md5puts)(m, "dft");
      X(md5int)(m, p->ri == p->ro);
-     X(md5ptrdiff)(m, p->ii - p->ri);
-     X(md5ptrdiff)(m, p->io - p->ro);
+     X(md5INT)(m, p->ii - p->ri);
+     X(md5INT)(m, p->io - p->ro);
      X(md5int)(m, X(alignment_of)(p->ri));
      X(md5int)(m, X(alignment_of)(p->ii));
      X(md5int)(m, X(alignment_of)(p->ro));
@@ -45,15 +44,15 @@ static void hash(const problem *p_, md5 *m)
      X(tensor_md5)(m, p->vecsz);
 }
 
-static void print(problem *ego_, printer *p)
+static void print(const problem *ego_, printer *p)
 {
      const problem_dft *ego = (const problem_dft *) ego_;
-     p->print(p, "(dft %d %d %d %td %td %T %T)", 
+     p->print(p, "(dft %d %d %d %D %D %T %T)", 
 	      ego->ri == ego->ro,
 	      X(alignment_of)(ego->ri),
 	      X(alignment_of)(ego->ro),
-	      ego->ii - ego->ri, 
-	      ego->io - ego->ro,
+	      (INT)(ego->ii - ego->ri), 
+	      (INT)(ego->io - ego->ro),
 	      ego->sz,
 	      ego->vecsz);
 }
@@ -68,26 +67,17 @@ static void zero(const problem *ego_)
 
 static const problem_adt padt =
 {
+     PROBLEM_DFT,
      hash,
      zero,
      print,
      destroy
 };
 
-int X(problem_dft_p)(const problem *p)
-{
-     return (p->adt == &padt);
-}
-
 problem *X(mkproblem_dft)(const tensor *sz, const tensor *vecsz,
-                          R *ri, R *ii, R *ro, R *io)
+			  R *ri, R *ii, R *ro, R *io)
 {
-     problem_dft *ego =
-          (problem_dft *)X(mkproblem)(sizeof(problem_dft), &padt);
-
-     A((ri == ro) == (ii == io)); /* both in place or both out of place */
-     A(X(tensor_kosherp)(sz));
-     A(X(tensor_kosherp)(vecsz));
+     problem_dft *ego;
 
      /* enforce pointer equality if untainted pointers are equal */
      if (UNTAINT(ri) == UNTAINT(ro))
@@ -99,6 +89,17 @@ problem *X(mkproblem_dft)(const tensor *sz, const tensor *vecsz,
      A(TAINTOF(ri) == TAINTOF(ii));
      A(TAINTOF(ro) == TAINTOF(io));
 
+     A(X(tensor_kosherp)(sz));
+     A(X(tensor_kosherp)(vecsz));
+
+     if (ri == ro || ii == io) {
+	  /* If either real or imag pointers are in place, both must be. */
+	  if (ri != ro || ii != io || !X(tensor_inplace_locations)(sz, vecsz))
+	       return X(mkproblem_unsolvable)();
+     }
+
+     ego = (problem_dft *)X(mkproblem)(sizeof(problem_dft), &padt);
+
      ego->sz = X(tensor_compress)(sz);
      ego->vecsz = X(tensor_compress_contiguous)(vecsz);
      ego->ri = ri;
@@ -112,10 +113,9 @@ problem *X(mkproblem_dft)(const tensor *sz, const tensor *vecsz,
 
 /* Same as X(mkproblem_dft), but also destroy input tensors. */
 problem *X(mkproblem_dft_d)(tensor *sz, tensor *vecsz,
-                            R *ri, R *ii, R *ro, R *io)
+			    R *ri, R *ii, R *ro, R *io)
 {
-     problem *p;
-     p = X(mkproblem_dft)(sz, vecsz, ri, ii, ro, io);
+     problem *p = X(mkproblem_dft)(sz, vecsz, ri, ii, ro, io);
      X(tensor_destroy2)(vecsz, sz);
      return p;
 }
