@@ -1,6 +1,6 @@
 /*
- * Copyright (c) 2003 Matteo Frigo
- * Copyright (c) 2003 Massachusetts Institute of Technology
+ * Copyright (c) 2003, 2007-14 Matteo Frigo
+ * Copyright (c) 2003, 2007-14 Massachusetts Institute of Technology
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -14,20 +14,19 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
  *
  */
 
-/* $Id: minmax.c,v 1.6 2003/03/15 20:29:43 stevenj Exp $ */
 
 #include "ifftw.h"
 
-int X(imax)(int a, int b)
+INT X(imax)(INT a, INT b)
 {
      return (a > b) ? a : b;
 }
 
-int X(imin)(int a, int b)
+INT X(imin)(INT a, INT b)
 {
      return (a < b) ? a : b;
 }
